@@ -194,7 +194,7 @@ used_ids = [
     BlockAllocation(88, 0xFFFF, "Road Vehicle"),
     BlockAllocation(11, 0xFFFF, "Ship"),
     BlockAllocation(41, 0xFFFF, "Aircraft"),
-    BlockAllocation(0, 255, "Station"),
+    BlockAllocation(0, 0xFFFE, "Station"),  # UINT16_MAX - 1
     BlockAllocation(0, 8, "Canal", False),
     BlockAllocation(0, 15, "Bridge", False),
     BlockAllocation(0, 255, "House"),
@@ -205,11 +205,12 @@ used_ids = [
     BlockAllocation(0, -1, "Sound"),
     BlockAllocation(0, 127, "Airport"),
     BlockAllocation(0, -1, "Signal", False),
-    BlockAllocation(0, 255, "Object"),
+    BlockAllocation(0, 64000, "Object"),
     BlockAllocation(0, 63, "Railtype"),
     BlockAllocation(0, 255, "Airport Tile"),
     BlockAllocation(0, 62, "Roadtype"),
     BlockAllocation(0, 62, "Tramtype"),
+    BlockAllocation(0, 0xFFFE, "RoadStop"),  # UINT16_MAX - 1
 ]
 
 
@@ -629,6 +630,9 @@ def parse_property(prop_info, value_list, feature, id):
                         "String used as value for non-string property: " + str(prop_info["num"]), value.pos
                     )
                 string_range = prop_info["string"]
+                if isinstance(string_range, tuple):
+                    threshold, below, above = string_range
+                    string_range = below if id.value < threshold else above
                 stringid, string_actions = action4.get_string_action4s(feature, string_range, value, id)
                 value = expression.ConstantNumeric(stringid)
                 action_list_append.extend(string_actions)
@@ -1079,10 +1083,10 @@ def parse_sort_block(feature, vehid_list):
 
 
 callback_flag_properties = {
-    0x00: {"size": 1, "num": 0x1E},
-    0x01: {"size": 1, "num": 0x17},
-    0x02: {"size": 1, "num": 0x12},
-    0x03: {"size": 1, "num": 0x14},
+    0x00: two_byte_property(0x1E, 0x31),
+    0x01: two_byte_property(0x17, 0x28),
+    0x02: two_byte_property(0x12, 0x22),
+    0x03: two_byte_property(0x14, 0x22),
     0x04: {"size": 1, "num": 0x0B},
     0x05: {"size": 1, "num": 0x08},
     0x07: two_byte_property(0x14, 0x1D),
@@ -1091,6 +1095,7 @@ callback_flag_properties = {
     0x0B: {"size": 1, "num": 0x1A},
     0x0F: {"size": 2, "num": 0x15},
     0x11: {"size": 1, "num": 0x0E},
+    0x14: {"size": 1, "num": 0x11},
 }
 
 
@@ -1119,11 +1124,9 @@ def get_callback_flags_actions(feature, id, flags):
     if not isinstance(prop_info_list, list):
         prop_info_list = [prop_info_list]
     for prop_info in prop_info_list:
-        act0.prop_list.append(
-            Action0Property(
-                prop_info["num"], parse_property_value(prop_info, expression.ConstantNumeric(flags)), prop_info["size"]
-            )
-        )
+        parsed_value = parse_property_value(prop_info, expression.ConstantNumeric(flags))
+        if parsed_value[0].value != 0:
+            act0.prop_list.append(Action0Property(prop_info["num"], parsed_value, prop_info["size"]))
 
     return [act0]
 
