@@ -130,7 +130,7 @@ constant_numbers = {
     "SHIP_FLAG_NO_BREAKDOWN_SMOKE": 6,
     "SHIP_FLAG_SPRITE_STACK": 7,
 
-    # aircrafts misc flags
+    # aircraft misc flags
     "AIRCRAFT_FLAG_2CC"  : 1,
     "AIRCRAFT_FLAG_AUTOREFIT": 4,
     "AIRCRAFT_FLAG_NO_BREAKDOWN_SMOKE": 6,
@@ -141,6 +141,12 @@ constant_numbers = {
     "VEHICLE_FLAG_AUTOREFIT": 4,
     "VEHICLE_FLAG_NO_BREAKDOWN_SMOKE": 6,
 
+    # vehicle extra flags
+    "VEHICLE_FLAG_DISABLE_NEW_VEHICLE_MESSAGE"    : 0,
+    "VEHICLE_FLAG_DISABLE_EXCLUSIVE_PREVIEW"      : 1,
+    "VEHICLE_FLAG_SYNC_VARIANT_EXCLUSIVE_PREVIEW" : 2,
+    "VEHICLE_FLAG_SYNC_VARIANT_RELIABILITY"       : 3,
+
     # Graphic flags for waterfeatures
     "WATERFEATURE_ALTERNATIVE_SPRITES" : 0,
 
@@ -367,6 +373,9 @@ constant_numbers = {
     "STAT_FLAG_CUSTOM_FOUNDATIONS"    : 3,
     "STAT_FLAG_EXTENDED_FOUNDATIONS"  : 4,
 
+    # station tiles
+    "STAT_ALL_TILES"     : 0xFF,
+
     # station animation triggers
     "STAT_ANIM_IS_BUILT"              : 0,
     "STAT_ANIM_CARGO_ARRIVES"         : 1,
@@ -804,6 +813,14 @@ constant_numbers = {
     "ANIM_TRIGGER_APT_250_TICKS"            : 4,
     "ANIM_TRIGGER_APT_AIRPLANE_LANDS"       : 5,
 
+    "ANIM_TRIGGER_ROAD_STOP_BUILT"          : 0,
+    "ANIM_TRIGGER_ROAD_STOP_NEW_CARGO"      : 1,
+    "ANIM_TRIGGER_ROAD_STOP_CARGO_TAKEN"    : 2,
+    "ANIM_TRIGGER_ROAD_STOP_VEH_ENTER"      : 3,
+    "ANIM_TRIGGER_ROAD_STOP_VEH_LEAVE"      : 4,
+    "ANIM_TRIGGER_ROAD_STOP_VEH_LOAD"       : 5,
+    "ANIM_TRIGGER_ROAD_STOP_250_TICKS"      : 6,
+
     # Animation looping
     "ANIMATION_NON_LOOPING"                 : 0,
     "ANIMATION_LOOPING"                     : 1,
@@ -1120,6 +1137,31 @@ constant_numbers = {
     "TTD_STR_ERROR_CAN_T_CONSTRUCT_THIS_INDUSTRY"           : 0x4830,
     "TTD_STR_ERROR_FOREST_CAN_ONLY_BE_PLANTED"              : 0x4831,
     "TTD_STR_ERROR_CAN_ONLY_BE_POSITIONED"                  : 0x483B,
+
+    # Road stops
+    "RST_AVAILABILITY_TYPE_PASSENGER"           : 0,
+    "RST_AVAILABILITY_TYPE_FREIGHT"             : 1,
+    "RST_AVAILABILITY_TYPE_ALL"                 : 2,
+
+    "RST_TYPE_BUS"                              : 0,
+    "RST_TYPE_TRUCK"                            : 1,
+
+    "RST_DRAW_FLAG_BAY_ROAD"                    : 0,
+    "RST_DRAW_FLAG_DRIVE_THROUGH_ROAD_OVERLAY"  : 1,
+
+    "RST_GENERAL_FLAG_RANDOM_ANIMATION"         : 0,
+    "RST_GENERAL_FLAG_NO_CATENARY"              : 2,
+    "RST_GENERAL_FLAG_DRIVE_THROUGH_ONLY"       : 3,
+    "RST_GENERAL_FLAG_NO_AUTO_ROAD_CONNECTION"  : 4,
+    "RST_GENERAL_FLAG_BUILD_MENU_ROAD_ONLY"     : 5,
+    "RST_GENERAL_FLAG_BUILD_MENU_TRAM_ONLY"     : 6,
+
+    "RST_VIEW_BAY_NE"                           : 0,
+    "RST_VIEW_BAY_SE"                           : 1,
+    "RST_VIEW_BAY_SW"                           : 2,
+    "RST_VIEW_BAY_NW"                           : 3,
+    "RST_VIEW_DRIVE_THROUGH_X"                  : 4,
+    "RST_VIEW_DRIVE_THROUGH_Y"                  : 5,
 }
 # fmt: on
 
@@ -1348,8 +1390,8 @@ def create_spritegroup_ref(name, info, pos):
 cargo_numbers = {}
 
 is_default_railtype_table = True
-# if no railtype_table is provided, OpenTTD assumes these 4 railtypes
-railtype_table = {"RAIL": 0, "ELRL": 1, "MONO": 1, "MGLV": 2}
+# if no railtype_table is provided, OpenTTD assumes these 3 railtypes
+railtype_table = {"RAIL": 0, "MONO": 1, "MGLV": 2}
 
 is_default_roadtype_table = True
 # if no roadtype_table is provided, OpenTTD sets all vehicles to ROAD
