@@ -16,7 +16,9 @@ with NML; if not, write to the Free Software Foundation, Inc.,
 """
 Abstract base classes that implements common functionality for output classes
 """
-import array, io
+import array
+import io
+
 
 class OutputBase:
     """
@@ -36,6 +38,7 @@ class OutputBase:
     @ivar file: Memory output file handle, if opened.
     @type file: C{file} or C{None}
     """
+
     def __init__(self, filename):
         self.filename = filename
         self.file = None
@@ -55,7 +58,6 @@ class OutputBase:
         """
         raise NotImplementedError("Implement me in {}".format(type(self)))
 
-
     def assemble_file(self, real_file):
         """
         File is about to be closed, last chance to append data.
@@ -77,9 +79,8 @@ class OutputBase:
         """
         Close the memory file, copy collected output to the real file.
         """
-        real_file = self.open_file()
-        self.assemble_file(real_file)
-        real_file.close()
+        with self.open_file() as real_file:
+            self.assemble_file(real_file)
         self.discard()
 
     def skip_sprite_checks(self):
@@ -116,6 +117,7 @@ class SpriteOutputBase(OutputBase):
     @ivar expected_count: Number of bytes expected in the current sprite.
     @type expected_count: C{int}
     """
+
     def __init__(self, filename):
         OutputBase.__init__(self, filename)
         self.in_sprite = False
@@ -139,7 +141,8 @@ class SpriteOutputBase(OutputBase):
         @precond: Must be outputting a sprite.
         """
         assert self.in_sprite
-        if -0x80 <= value < 0 : value += 0x100
+        if -0x80 <= value < 0:
+            value += 0x100
         assert value >= 0 and value <= 0xFF
         self.byte_count += 1
         return value
@@ -157,7 +160,8 @@ class SpriteOutputBase(OutputBase):
         @precond: Must be outputting a sprite.
         """
         assert self.in_sprite
-        if -0x8000 <= value < 0: value += 0x10000
+        if -0x8000 <= value < 0:
+            value += 0x10000
         assert value >= 0 and value <= 0xFFFF
         self.byte_count += 2
         return value
@@ -175,7 +179,8 @@ class SpriteOutputBase(OutputBase):
         @precond: Must be outputting a sprite.
         """
         assert self.in_sprite
-        if -0x80000000 <= value < 0: value += 0x100000000
+        if -0x80000000 <= value < 0:
+            value += 0x100000000
         assert value >= 0 and value <= 0xFFFFFFFF
         self.byte_count += 4
         return value
@@ -200,9 +205,9 @@ class SpriteOutputBase(OutputBase):
         elif size == 4:
             self.print_dwordx(value)
         else:
-            assert False
+            raise AssertionError()
 
-    def print_bytex(self, byte, pretty_print = None):
+    def print_bytex(self, byte, pretty_print=None):
         """
         Output an unsigned byte.
 
@@ -229,7 +234,7 @@ class SpriteOutputBase(OutputBase):
         """
         raise NotImplementedError("Implement print_dwordx() in {}".format(type(self)))
 
-    def newline(self, msg = "", prefix = "\t"):
+    def newline(self, msg="", prefix="\t"):
         """
         Output a line separator, prefixed with L{prefix}, C{"// "}, and the
         L{msg}, if the latter is not empty.
@@ -253,14 +258,17 @@ class SpriteOutputBase(OutputBase):
         """
         raise NotImplementedError("Implement comment() in {}".format(type(self)))
 
-
-    def start_sprite(self, expected_size):
+    def start_sprite(self, expected_size, is_real_sprite=False):
         """
         Note to the output stream that a sprite is about to be written.
 
         @param expected_size: Expected size of the sprite data.
         @type  expected_size: C{int}
+
+        @param is_real_sprite: Self-explanatory.
+        @type  is_real_sprite: C{bool}
         """
+        del is_real_sprite  # unused in base impl.
         assert not self.in_sprite
         self.in_sprite = True
         self.expected_count = expected_size
@@ -275,13 +283,16 @@ class SpriteOutputBase(OutputBase):
         assert self.in_sprite
         self.in_sprite = False
         self.newline()
-        assert self.expected_count == self.byte_count, "Expected {:d} bytes to be written to sprite, got {:d}".format(self.expected_count, self.byte_count)
+        assert self.expected_count == self.byte_count, "Expected {:d} bytes to be written to sprite, got {:d}".format(
+            self.expected_count, self.byte_count
+        )
 
 
 class TextOutputBase(OutputBase):
     """
     Base class for textual output.
     """
+
     def __init__(self, filename):
         OutputBase.__init__(self, filename)
 
@@ -293,13 +304,14 @@ class BinaryOutputBase(SpriteOutputBase):
     """
     Class for binary output.
     """
+
     def __init__(self, filename):
         SpriteOutputBase.__init__(self, filename)
 
     def open(self):
-        self.file = array.array('B')
+        self.file = array.array("B")
 
-    def newline(self, msg = "", prefix = "\t"):
+    def newline(self, msg="", prefix="\t"):
         pass
 
     def print_data(self, data):
@@ -319,7 +331,7 @@ class BinaryOutputBase(SpriteOutputBase):
         value = self.prepare_byte(value)
         self.wb(value)
 
-    def print_bytex(self, value, pretty_print = None):
+    def print_bytex(self, value, pretty_print=None):
         self.print_byte(value)
 
     def print_word(self, value):
